@@ -787,7 +787,7 @@ def unzip(file_name, dst_dir=None):
 
 def get_last_commit_sha_by_branch(git_host, git_token, git_project_id, git_branch):
     url = '%s/api/v4/projects/%s/repository/commits/%s' % (
-        git_host, git_project_id, git_branch)
+        git_host, git_project_id, quote(git_branch, 'utf-8'))
     res = requests.request('GET', url,
                            params={
                                'private_token': git_token
@@ -807,14 +807,14 @@ def get_gitlab_last_pipeline_id_by_branch(git_host, git_token, git_project_id, g
                            params={
                                'private_token': git_token,
                                'status': 'success',
-                               'ref': git_branch,
+                               'ref': quote(git_branch, 'utf-8'),
                                'per_page': 1,
                                'order_by': 'id',
                                'sort': 'desc'
                            },
                            stream=True)
 
-    if len(res) == 1 and res.status_code == 200:
+    if res.status_code == 200:
         return json.loads(res.content)[0]['id']
     else:
         raise Exception('pipeline id get failure %s %s' % (url, res.status_code))
